/*
 *  Header file for defining ioctl() flag values.  Since the structures
 *  within the tape driver are only used internally, they needn't be
 *  defined here.
 *
 *	IOCTL support for the Archive Viper
 *	Copyright (c) 1991 by Frank J. Edwards.
 */

#ifndef _SYS_VIPER_H
#define _SYS_VIPER_H

#include "sys/ioccom.h"

/*
 *  The next commands take an integer as a parameter.  The integer
 *  is a bit mask of which debug options to turn on or off.  Note that
 *  to set a particular state, you would need to turn off all bits
 *  and turn on just the ones you want.
 */

#define VIODBGON    _IOR('t', 1, int)   /* Enable debugging modes */
#define VIODBGOFF   _IOW('t', 2, int)   /* Disable debugging modes */

#define VIO_GENERAL         0x0001      /* Print general debug info */
#define VIO_DEFAULT         0x0002      /* Complain about "default:"'s taken */
#define VIO_NON_IO          0x0004      /* Only non I/O requests */
#define VIO_IO              0x0008      /* Only I/O requests */
#define VIO_STATEDATA       0x0010      /* Only state changes data */
#define VIO_GETSENSE        0x0020      /* Only GETSENSE requests */
#define VIO_ERROR           0x0040      /* Additional info on errors */

#define VIO_ALL             0x007F      /* All valid bit positions */

/*
 *  The following commands take a parameter which is a pointer to
 *  a structure containing the address at which to store the return
 *  data and an integer describing the amount of memory for it.
 */

struct vio_arg {
    int     vio_len;        /* How much is at 'vio_addr'? */
    char    vio_addr[1];    /* Start of data space */
};

#define VIOINQ      _IOR('t', 129, caddr_t)     /* Inquiry data */
#define VIOMSENS    _IOR('t', 130, caddr_t)     /* Mode Sense data */
#define VIOMSEL     _IOW('t', 131, caddr_t)     /* Mode Select data */
#define VIORSENS    _IOR('t', 132, caddr_t)     /* Request Sense data */

#endif /* _SYS_VIPER_H */
